/*
 * Copyright (C) 2010-2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "NetworkProcess.h"

#include "ArgumentCoders.h"
#include "Attachment.h"
#include "CacheModel.h"
#include "CallbackID.h"
#include "DataReference.h"
#include "Decoder.h"
#include "DownloadID.h"
#include "DownloadManager.h"
#include "HandleMessage.h"
#include "LocalStorageDatabaseTracker.h"
#include "NavigatingToAppBoundDomain.h"
#include "NetworkProcessCreationParameters.h"
#include "NetworkProcessMessages.h"
#include "SandboxExtension.h"
#if ENABLE(RESOURCE_LOAD_STATISTICS)
#include "ShouldGrandfatherStatistics.h"
#endif
#include "WebCoreArgumentCoders.h"
#include "WebPageProxyIdentifier.h"
#if ENABLE(RESOURCE_LOAD_STATISTICS)
#include "WebResourceLoadStatisticsStore.h"
#endif
#include "WebsiteDataFetchOption.h"
#include "WebsiteDataStoreParameters.h"
#include "WebsiteDataType.h"
#include <WebCore/CertificateInfo.h>
#if ENABLE(RESOURCE_LOAD_STATISTICS)
#include <WebCore/CrossSiteNavigationDataTransfer.h>
#endif
#if USE(CURL)
#include <WebCore/CurlProxySettings.h>
#endif
#include <WebCore/HTTPCookieAcceptPolicy.h>
#if ENABLE(RESOURCE_LOAD_STATISTICS)
#include <WebCore/NetworkStorageSession.h>
#endif
#include <WebCore/PageIdentifier.h>
#include <WebCore/PrivateClickMeasurement.h>
#include <WebCore/ProcessIdentifier.h>
#include <WebCore/RegistrableDomain.h>
#include <WebCore/ResourceRequest.h>
#include <WebCore/SecurityOriginData.h>
#if USE(SOUP)
#include <WebCore/SoupNetworkProxySettings.h>
#endif
#include <WebCore/StoredCredentialsPolicy.h>
#include <pal/SessionID.h>
#if (ENABLE(RESOURCE_LOAD_STATISTICS) && ENABLE(APP_BOUND_DOMAINS))
#include <wtf/HashSet.h>
#endif
#include <wtf/OptionSet.h>
#include <wtf/Optional.h>
#include <wtf/Seconds.h>
#include <wtf/Vector.h>
#include <wtf/WallTime.h>
#include <wtf/text/WTFString.h>

namespace Messages {

namespace NetworkProcess {

void CreateNetworkConnectionToWebProcess::callReply(IPC::Decoder& decoder, CompletionHandler<void(Optional<IPC::Attachment>&&, WebCore::HTTPCookieAcceptPolicy&&)>&& completionHandler)
{
    Optional<Optional<IPC::Attachment>> connectionIdentifier;
    decoder >> connectionIdentifier;
    if (!connectionIdentifier) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    Optional<WebCore::HTTPCookieAcceptPolicy> cookieAcceptPolicy;
    decoder >> cookieAcceptPolicy;
    if (!cookieAcceptPolicy) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*connectionIdentifier), WTFMove(*cookieAcceptPolicy));
}

void CreateNetworkConnectionToWebProcess::cancelReply(CompletionHandler<void(Optional<IPC::Attachment>&&, WebCore::HTTPCookieAcceptPolicy&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<Optional<IPC::Attachment>>::create(), IPC::AsyncReplyError<WebCore::HTTPCookieAcceptPolicy>::create());
}

void CreateNetworkConnectionToWebProcess::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const Optional<IPC::Attachment>& connectionIdentifier, WebCore::HTTPCookieAcceptPolicy cookieAcceptPolicy)
{
    *encoder << connectionIdentifier;
    *encoder << cookieAcceptPolicy;
    connection.sendSyncReply(WTFMove(encoder));
}

void RenameOriginInWebsiteData::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void RenameOriginInWebsiteData::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void RenameOriginInWebsiteData::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void CancelDownload::callReply(IPC::Decoder& decoder, CompletionHandler<void(IPC::DataReference&&)>&& completionHandler)
{
    Optional<IPC::DataReference> resumeData;
    decoder >> resumeData;
    if (!resumeData) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*resumeData));
}

void CancelDownload::cancelReply(CompletionHandler<void(IPC::DataReference&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<IPC::DataReference>::create());
}

void CancelDownload::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const IPC::DataReference& resumeData)
{
    *encoder << resumeData;
    connection.sendSyncReply(WTFMove(encoder));
}

void SetAllowsAnySSLCertificateForWebSocket::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void FlushCookies::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void FlushCookies::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void FlushCookies::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void SetCacheModelSynchronouslyForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void ProcessWillSuspendImminentlyForTestingSync::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void PrepareToSuspend::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void PrepareToSuspend::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void PrepareToSuspend::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void ClearPrevalentResource::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearPrevalentResource::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearPrevalentResource::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void ClearUserInteraction::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearUserInteraction::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearUserInteraction::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void DumpResourceLoadStatistics::callReply(IPC::Decoder& decoder, CompletionHandler<void(String&&)>&& completionHandler)
{
    Optional<String> dumpedStatistics;
    decoder >> dumpedStatistics;
    if (!dumpedStatistics) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*dumpedStatistics));
}

void DumpResourceLoadStatistics::cancelReply(CompletionHandler<void(String&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<String>::create());
}

void DumpResourceLoadStatistics::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const String& dumpedStatistics)
{
    *encoder << dumpedStatistics;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void UpdatePrevalentDomainsToBlockCookiesFor::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void UpdatePrevalentDomainsToBlockCookiesFor::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void UpdatePrevalentDomainsToBlockCookiesFor::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void IsGrandfathered::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> isGrandfathered;
    decoder >> isGrandfathered;
    if (!isGrandfathered) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*isGrandfathered));
}

void IsGrandfathered::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void IsGrandfathered::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool isGrandfathered)
{
    *encoder << isGrandfathered;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void IsPrevalentResource::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> isPrevalent;
    decoder >> isPrevalent;
    if (!isPrevalent) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*isPrevalent));
}

void IsPrevalentResource::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void IsPrevalentResource::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool isPrevalent)
{
    *encoder << isPrevalent;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void IsVeryPrevalentResource::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> isVeryPrevalent;
    decoder >> isVeryPrevalent;
    if (!isVeryPrevalent) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*isVeryPrevalent));
}

void IsVeryPrevalentResource::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void IsVeryPrevalentResource::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool isVeryPrevalent)
{
    *encoder << isVeryPrevalent;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetAgeCapForClientSideCookies::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetAgeCapForClientSideCookies::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetAgeCapForClientSideCookies::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetLastSeen::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetLastSeen::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetLastSeen::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void MergeStatisticForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void MergeStatisticForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void MergeStatisticForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void InsertExpiredStatisticForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void InsertExpiredStatisticForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void InsertExpiredStatisticForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetPrevalentResource::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrevalentResource::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrevalentResource::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetPrevalentResourceForDebugMode::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrevalentResourceForDebugMode::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrevalentResourceForDebugMode::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void IsResourceLoadStatisticsEphemeral::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> isEphemeral;
    decoder >> isEphemeral;
    if (!isEphemeral) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*isEphemeral));
}

void IsResourceLoadStatisticsEphemeral::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void IsResourceLoadStatisticsEphemeral::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool isEphemeral)
{
    *encoder << isEphemeral;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void HadUserInteraction::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> hadUserInteraction;
    decoder >> hadUserInteraction;
    if (!hadUserInteraction) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*hadUserInteraction));
}

void HadUserInteraction::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void HadUserInteraction::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool hadUserInteraction)
{
    *encoder << hadUserInteraction;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void IsRelationshipOnlyInDatabaseOnce::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> hadUserInteraction;
    decoder >> hadUserInteraction;
    if (!hadUserInteraction) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*hadUserInteraction));
}

void IsRelationshipOnlyInDatabaseOnce::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void IsRelationshipOnlyInDatabaseOnce::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool hadUserInteraction)
{
    *encoder << hadUserInteraction;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void HasLocalStorage::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> hadUserInteraction;
    decoder >> hadUserInteraction;
    if (!hadUserInteraction) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*hadUserInteraction));
}

void HasLocalStorage::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void HasLocalStorage::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool hadUserInteraction)
{
    *encoder << hadUserInteraction;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void GetAllStorageAccessEntries::callReply(IPC::Decoder& decoder, CompletionHandler<void(Vector<String>&&)>&& completionHandler)
{
    Optional<Vector<String>> domains;
    decoder >> domains;
    if (!domains) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*domains));
}

void GetAllStorageAccessEntries::cancelReply(CompletionHandler<void(Vector<String>&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<Vector<String>>::create());
}

void GetAllStorageAccessEntries::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const Vector<String>& domains)
{
    *encoder << domains;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void IsRegisteredAsRedirectingTo::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> isRedirectingTo;
    decoder >> isRedirectingTo;
    if (!isRedirectingTo) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*isRedirectingTo));
}

void IsRegisteredAsRedirectingTo::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void IsRegisteredAsRedirectingTo::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool isRedirectingTo)
{
    *encoder << isRedirectingTo;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void IsRegisteredAsSubFrameUnder::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> isSubframeUnder;
    decoder >> isSubframeUnder;
    if (!isSubframeUnder) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*isSubframeUnder));
}

void IsRegisteredAsSubFrameUnder::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void IsRegisteredAsSubFrameUnder::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool isSubframeUnder)
{
    *encoder << isSubframeUnder;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void IsRegisteredAsSubresourceUnder::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> isSubresourceUnder;
    decoder >> isSubresourceUnder;
    if (!isSubresourceUnder) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*isSubresourceUnder));
}

void IsRegisteredAsSubresourceUnder::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void IsRegisteredAsSubresourceUnder::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool isSubresourceUnder)
{
    *encoder << isSubresourceUnder;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void DomainIDExistsInDatabase::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> exists;
    decoder >> exists;
    if (!exists) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*exists));
}

void DomainIDExistsInDatabase::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void DomainIDExistsInDatabase::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool exists)
{
    *encoder << exists;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void LogUserInteraction::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void LogUserInteraction::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void LogUserInteraction::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void ResetParametersToDefaultValues::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ResetParametersToDefaultValues::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ResetParametersToDefaultValues::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void ScheduleClearInMemoryAndPersistent::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ScheduleClearInMemoryAndPersistent::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ScheduleClearInMemoryAndPersistent::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void ScheduleCookieBlockingUpdate::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ScheduleCookieBlockingUpdate::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ScheduleCookieBlockingUpdate::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void ScheduleStatisticsAndDataRecordsProcessing::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ScheduleStatisticsAndDataRecordsProcessing::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ScheduleStatisticsAndDataRecordsProcessing::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void StatisticsDatabaseHasAllTables::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> hasAllTables;
    decoder >> hasAllTables;
    if (!hasAllTables) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*hasAllTables));
}

void StatisticsDatabaseHasAllTables::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void StatisticsDatabaseHasAllTables::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool hasAllTables)
{
    *encoder << hasAllTables;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetCacheMaxAgeCapForPrevalentResources::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetCacheMaxAgeCapForPrevalentResources::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetCacheMaxAgeCapForPrevalentResources::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetGrandfathered::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetGrandfathered::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetGrandfathered::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void GetResourceLoadStatisticsDataSummary::callReply(IPC::Decoder& decoder, CompletionHandler<void(Vector<WebKit::WebResourceLoadStatisticsStore::ThirdPartyData>&&)>&& completionHandler)
{
    Optional<Vector<WebKit::WebResourceLoadStatisticsStore::ThirdPartyData>> thirdPartyData;
    decoder >> thirdPartyData;
    if (!thirdPartyData) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*thirdPartyData));
}

void GetResourceLoadStatisticsDataSummary::cancelReply(CompletionHandler<void(Vector<WebKit::WebResourceLoadStatisticsStore::ThirdPartyData>&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<Vector<WebKit::WebResourceLoadStatisticsStore::ThirdPartyData>>::create());
}

void GetResourceLoadStatisticsDataSummary::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const Vector<WebKit::WebResourceLoadStatisticsStore::ThirdPartyData>& thirdPartyData)
{
    *encoder << thirdPartyData;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetGrandfatheringTime::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetGrandfatheringTime::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetGrandfatheringTime::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetMaxStatisticsEntries::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetMaxStatisticsEntries::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetMaxStatisticsEntries::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetMinimumTimeBetweenDataRecordsRemoval::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetMinimumTimeBetweenDataRecordsRemoval::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetMinimumTimeBetweenDataRecordsRemoval::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetPruneEntriesDownTo::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPruneEntriesDownTo::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPruneEntriesDownTo::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetShouldClassifyResourcesBeforeDataRecordsRemoval::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetShouldClassifyResourcesBeforeDataRecordsRemoval::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetShouldClassifyResourcesBeforeDataRecordsRemoval::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetNotifyPagesWhenDataRecordsWereScanned::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetNotifyPagesWhenDataRecordsWereScanned::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetNotifyPagesWhenDataRecordsWereScanned::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetIsRunningResourceLoadStatisticsTest::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetIsRunningResourceLoadStatisticsTest::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetIsRunningResourceLoadStatisticsTest::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetResourceLoadStatisticsDebugMode::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetResourceLoadStatisticsDebugMode::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetResourceLoadStatisticsDebugMode::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetVeryPrevalentResource::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetVeryPrevalentResource::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetVeryPrevalentResource::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetSubframeUnderTopFrameDomain::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetSubframeUnderTopFrameDomain::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetSubframeUnderTopFrameDomain::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetSubresourceUnderTopFrameDomain::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetSubresourceUnderTopFrameDomain::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetSubresourceUnderTopFrameDomain::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetSubresourceUniqueRedirectTo::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetSubresourceUniqueRedirectTo::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetSubresourceUniqueRedirectTo::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetSubresourceUniqueRedirectFrom::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetSubresourceUniqueRedirectFrom::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetSubresourceUniqueRedirectFrom::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetTimeToLiveUserInteraction::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetTimeToLiveUserInteraction::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetTimeToLiveUserInteraction::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetTopFrameUniqueRedirectTo::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetTopFrameUniqueRedirectTo::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetTopFrameUniqueRedirectTo::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetTopFrameUniqueRedirectFrom::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetTopFrameUniqueRedirectFrom::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetTopFrameUniqueRedirectFrom::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void ResetCacheMaxAgeCapForPrevalentResources::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ResetCacheMaxAgeCapForPrevalentResources::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ResetCacheMaxAgeCapForPrevalentResources::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetCrossSiteLoadWithLinkDecorationForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetCrossSiteLoadWithLinkDecorationForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetCrossSiteLoadWithLinkDecorationForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void ResetCrossSiteLoadsWithLinkDecorationForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ResetCrossSiteLoadsWithLinkDecorationForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ResetCrossSiteLoadsWithLinkDecorationForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void DeleteCookiesForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void DeleteCookiesForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void DeleteCookiesForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void HasIsolatedSession::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> hasIsolatedSession;
    decoder >> hasIsolatedSession;
    if (!hasIsolatedSession) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*hasIsolatedSession));
}

void HasIsolatedSession::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void HasIsolatedSession::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool hasIsolatedSession)
{
    *encoder << hasIsolatedSession;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if (ENABLE(RESOURCE_LOAD_STATISTICS) && ENABLE(APP_BOUND_DOMAINS))

void SetAppBoundDomainsForResourceLoadStatistics::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetAppBoundDomainsForResourceLoadStatistics::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetAppBoundDomainsForResourceLoadStatistics::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetShouldDowngradeReferrerForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetShouldDowngradeReferrerForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetShouldDowngradeReferrerForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetThirdPartyCookieBlockingMode::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetThirdPartyCookieBlockingMode::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetThirdPartyCookieBlockingMode::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetShouldEnbleSameSiteStrictEnforcementForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetShouldEnbleSameSiteStrictEnforcementForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetShouldEnbleSameSiteStrictEnforcementForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetFirstPartyWebsiteDataRemovalModeForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetFirstPartyWebsiteDataRemovalModeForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetFirstPartyWebsiteDataRemovalModeForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetToSameSiteStrictCookiesForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetToSameSiteStrictCookiesForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetToSameSiteStrictCookiesForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetFirstPartyHostCNAMEDomainForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetFirstPartyHostCNAMEDomainForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetFirstPartyHostCNAMEDomainForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(RESOURCE_LOAD_STATISTICS)

void SetThirdPartyCNAMEDomainForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetThirdPartyCNAMEDomainForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetThirdPartyCNAMEDomainForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

void SyncLocalStorage::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SyncLocalStorage::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SyncLocalStorage::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void DumpPrivateClickMeasurement::callReply(IPC::Decoder& decoder, CompletionHandler<void(String&&)>&& completionHandler)
{
    Optional<String> privateClickMeasurementState;
    decoder >> privateClickMeasurementState;
    if (!privateClickMeasurementState) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*privateClickMeasurementState));
}

void DumpPrivateClickMeasurement::cancelReply(CompletionHandler<void(String&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<String>::create());
}

void DumpPrivateClickMeasurement::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const String& privateClickMeasurementState)
{
    *encoder << privateClickMeasurementState;
    connection.sendSyncReply(WTFMove(encoder));
}

void ClearPrivateClickMeasurement::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearPrivateClickMeasurement::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearPrivateClickMeasurement::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void SetPrivateClickMeasurementOverrideTimerForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrivateClickMeasurementOverrideTimerForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrivateClickMeasurementOverrideTimerForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void MarkAttributedPrivateClickMeasurementsAsExpiredForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void MarkAttributedPrivateClickMeasurementsAsExpiredForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void MarkAttributedPrivateClickMeasurementsAsExpiredForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void SimulateResourceLoadStatisticsSessionRestart::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SimulateResourceLoadStatisticsSessionRestart::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SimulateResourceLoadStatisticsSessionRestart::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void SetPrivateClickMeasurementTokenPublicKeyURLForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrivateClickMeasurementTokenPublicKeyURLForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrivateClickMeasurementTokenPublicKeyURLForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void SetPrivateClickMeasurementTokenSignatureURLForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrivateClickMeasurementTokenSignatureURLForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrivateClickMeasurementTokenSignatureURLForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void SetPrivateClickMeasurementAttributionReportURLForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrivateClickMeasurementAttributionReportURLForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetPrivateClickMeasurementAttributionReportURLForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void MarkPrivateClickMeasurementsAsExpiredForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void MarkPrivateClickMeasurementsAsExpiredForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void MarkPrivateClickMeasurementsAsExpiredForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void SetFraudPreventionValuesForTesting::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetFraudPreventionValuesForTesting::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void SetFraudPreventionValuesForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void GetLocalStorageOriginDetails::callReply(IPC::Decoder& decoder, CompletionHandler<void(Vector<WebKit::LocalStorageDatabaseTracker::OriginDetails>&&)>&& completionHandler)
{
    Optional<Vector<WebKit::LocalStorageDatabaseTracker::OriginDetails>> details;
    decoder >> details;
    if (!details) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*details));
}

void GetLocalStorageOriginDetails::cancelReply(CompletionHandler<void(Vector<WebKit::LocalStorageDatabaseTracker::OriginDetails>&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<Vector<WebKit::LocalStorageDatabaseTracker::OriginDetails>>::create());
}

void GetLocalStorageOriginDetails::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const Vector<WebKit::LocalStorageDatabaseTracker::OriginDetails>& details)
{
    *encoder << details;
    connection.sendSyncReply(WTFMove(encoder));
}

void SetServiceWorkerFetchTimeoutForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void ResetServiceWorkerFetchTimeoutForTesting::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void ResetQuota::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ResetQuota::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ResetQuota::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#if ENABLE(APP_BOUND_DOMAINS)

void HasAppBoundSession::callReply(IPC::Decoder& decoder, CompletionHandler<void(bool&&)>&& completionHandler)
{
    Optional<bool> hasAppBoundSession;
    decoder >> hasAppBoundSession;
    if (!hasAppBoundSession) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*hasAppBoundSession));
}

void HasAppBoundSession::cancelReply(CompletionHandler<void(bool&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<bool>::create());
}

void HasAppBoundSession::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, bool hasAppBoundSession)
{
    *encoder << hasAppBoundSession;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if ENABLE(APP_BOUND_DOMAINS)

void ClearAppBoundSession::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearAppBoundSession::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearAppBoundSession::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)

void ClearServiceWorkerEntitlementOverride::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearServiceWorkerEntitlementOverride::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearServiceWorkerEntitlementOverride::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

void UpdateBundleIdentifier::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void UpdateBundleIdentifier::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void UpdateBundleIdentifier::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

void ClearBundleIdentifier::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearBundleIdentifier::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearBundleIdentifier::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#if PLATFORM(COCOA)

void AppBoundNavigationData::callReply(IPC::Decoder& decoder, CompletionHandler<void(WebKit::AppBoundNavigationTestingData&&)>&& completionHandler)
{
    Optional<WebKit::AppBoundNavigationTestingData> data;
    decoder >> data;
    if (!data) {
        ASSERT_NOT_REACHED();
        cancelReply(WTFMove(completionHandler));
        return;
    }
    completionHandler(WTFMove(*data));
}

void AppBoundNavigationData::cancelReply(CompletionHandler<void(WebKit::AppBoundNavigationTestingData&&)>&& completionHandler)
{
    completionHandler(IPC::AsyncReplyError<WebKit::AppBoundNavigationTestingData>::create());
}

void AppBoundNavigationData::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const WebKit::AppBoundNavigationTestingData& data)
{
    *encoder << data;
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

#if PLATFORM(COCOA)

void ClearAppBoundNavigationData::callReply(IPC::Decoder& decoder, CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearAppBoundNavigationData::cancelReply(CompletionHandler<void()>&& completionHandler)
{
    completionHandler();
}

void ClearAppBoundNavigationData::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection)
{
    connection.sendSyncReply(WTFMove(encoder));
}

#endif

} // namespace NetworkProcess

} // namespace Messages

namespace WebKit {

void NetworkProcess::didReceiveNetworkProcessMessage(IPC::Connection& connection, IPC::Decoder& decoder)
{
    auto protectedThis = makeRef(*this);
    if (decoder.messageName() == Messages::NetworkProcess::InitializeNetworkProcess::name()) {
        IPC::handleMessage<Messages::NetworkProcess::InitializeNetworkProcess>(decoder, this, &NetworkProcess::initializeNetworkProcess);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::CreateNetworkConnectionToWebProcess::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::CreateNetworkConnectionToWebProcess>(connection, decoder, this, &NetworkProcess::createNetworkConnectionToWebProcess);
        return;
    }
#if USE(SOUP)
    if (decoder.messageName() == Messages::NetworkProcess::SetIgnoreTLSErrors::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetIgnoreTLSErrors>(decoder, this, &NetworkProcess::setIgnoreTLSErrors);
        return;
    }
#endif
#if USE(SOUP)
    if (decoder.messageName() == Messages::NetworkProcess::UserPreferredLanguagesChanged::name()) {
        IPC::handleMessage<Messages::NetworkProcess::UserPreferredLanguagesChanged>(decoder, this, &NetworkProcess::userPreferredLanguagesChanged);
        return;
    }
#endif
#if USE(SOUP)
    if (decoder.messageName() == Messages::NetworkProcess::SetNetworkProxySettings::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetNetworkProxySettings>(decoder, this, &NetworkProcess::setNetworkProxySettings);
        return;
    }
#endif
#if USE(SOUP)
    if (decoder.messageName() == Messages::NetworkProcess::PrefetchDNS::name()) {
        IPC::handleMessage<Messages::NetworkProcess::PrefetchDNS>(decoder, this, &NetworkProcess::prefetchDNS);
        return;
    }
#endif
#if USE(SOUP)
    if (decoder.messageName() == Messages::NetworkProcess::SetPersistentCredentialStorageEnabled::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetPersistentCredentialStorageEnabled>(decoder, this, &NetworkProcess::setPersistentCredentialStorageEnabled);
        return;
    }
#endif
#if USE(CURL)
    if (decoder.messageName() == Messages::NetworkProcess::SetNetworkProxySettings::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetNetworkProxySettings>(decoder, this, &NetworkProcess::setNetworkProxySettings);
        return;
    }
#endif
    if (decoder.messageName() == Messages::NetworkProcess::ClearCachedCredentials::name()) {
        IPC::handleMessage<Messages::NetworkProcess::ClearCachedCredentials>(decoder, this, &NetworkProcess::clearCachedCredentials);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::AddWebsiteDataStore::name()) {
        IPC::handleMessage<Messages::NetworkProcess::AddWebsiteDataStore>(decoder, this, &NetworkProcess::addWebsiteDataStore);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::DestroySession::name()) {
        IPC::handleMessage<Messages::NetworkProcess::DestroySession>(decoder, this, &NetworkProcess::destroySession);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::FetchWebsiteData::name()) {
        IPC::handleMessage<Messages::NetworkProcess::FetchWebsiteData>(decoder, this, &NetworkProcess::fetchWebsiteData);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::DeleteWebsiteData::name()) {
        IPC::handleMessage<Messages::NetworkProcess::DeleteWebsiteData>(decoder, this, &NetworkProcess::deleteWebsiteData);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::DeleteWebsiteDataForOrigins::name()) {
        IPC::handleMessage<Messages::NetworkProcess::DeleteWebsiteDataForOrigins>(decoder, this, &NetworkProcess::deleteWebsiteDataForOrigins);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::RenameOriginInWebsiteData::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::RenameOriginInWebsiteData>(connection, decoder, this, &NetworkProcess::renameOriginInWebsiteData);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::DownloadRequest::name()) {
        IPC::handleMessage<Messages::NetworkProcess::DownloadRequest>(decoder, this, &NetworkProcess::downloadRequest);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ResumeDownload::name()) {
        IPC::handleMessage<Messages::NetworkProcess::ResumeDownload>(decoder, this, &NetworkProcess::resumeDownload);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::CancelDownload::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::CancelDownload>(connection, decoder, this, &NetworkProcess::cancelDownload);
        return;
    }
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::NetworkProcess::PublishDownloadProgress::name()) {
        IPC::handleMessage<Messages::NetworkProcess::PublishDownloadProgress>(decoder, this, &NetworkProcess::publishDownloadProgress);
        return;
    }
#endif
    if (decoder.messageName() == Messages::NetworkProcess::ApplicationDidEnterBackground::name()) {
        IPC::handleMessage<Messages::NetworkProcess::ApplicationDidEnterBackground>(decoder, this, &NetworkProcess::applicationDidEnterBackground);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ApplicationWillEnterForeground::name()) {
        IPC::handleMessage<Messages::NetworkProcess::ApplicationWillEnterForeground>(decoder, this, &NetworkProcess::applicationWillEnterForeground);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ContinueWillSendRequest::name()) {
        IPC::handleMessage<Messages::NetworkProcess::ContinueWillSendRequest>(decoder, this, &NetworkProcess::continueWillSendRequest);
        return;
    }
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::NetworkProcess::SetQOS::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetQOS>(decoder, this, &NetworkProcess::setQOS);
        return;
    }
#endif
    if (decoder.messageName() == Messages::NetworkProcess::FlushCookies::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::FlushCookies>(connection, decoder, this, &NetworkProcess::flushCookies);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::AllowSpecificHTTPSCertificateForHost::name()) {
        IPC::handleMessage<Messages::NetworkProcess::AllowSpecificHTTPSCertificateForHost>(decoder, this, &NetworkProcess::allowSpecificHTTPSCertificateForHost);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SetCacheModel::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetCacheModel>(decoder, this, &NetworkProcess::setCacheModel);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ProcessDidTransitionToBackground::name()) {
        IPC::handleMessage<Messages::NetworkProcess::ProcessDidTransitionToBackground>(decoder, this, &NetworkProcess::processDidTransitionToBackground);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ProcessDidTransitionToForeground::name()) {
        IPC::handleMessage<Messages::NetworkProcess::ProcessDidTransitionToForeground>(decoder, this, &NetworkProcess::processDidTransitionToForeground);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::PrepareToSuspend::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::PrepareToSuspend>(connection, decoder, this, &NetworkProcess::prepareToSuspend);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ProcessDidResume::name()) {
        IPC::handleMessage<Messages::NetworkProcess::ProcessDidResume>(decoder, this, &NetworkProcess::processDidResume);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::PreconnectTo::name()) {
        IPC::handleMessage<Messages::NetworkProcess::PreconnectTo>(decoder, this, &NetworkProcess::preconnectTo);
        return;
    }
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::ClearPrevalentResource::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ClearPrevalentResource>(connection, decoder, this, &NetworkProcess::clearPrevalentResource);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::ClearUserInteraction::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ClearUserInteraction>(connection, decoder, this, &NetworkProcess::clearUserInteraction);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::DumpResourceLoadStatistics::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::DumpResourceLoadStatistics>(connection, decoder, this, &NetworkProcess::dumpResourceLoadStatistics);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetResourceLoadStatisticsEnabled::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetResourceLoadStatisticsEnabled>(decoder, this, &NetworkProcess::setResourceLoadStatisticsEnabled);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetResourceLoadStatisticsLogTestingEvent::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetResourceLoadStatisticsLogTestingEvent>(decoder, this, &NetworkProcess::setResourceLoadStatisticsLogTestingEvent);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::UpdatePrevalentDomainsToBlockCookiesFor::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::UpdatePrevalentDomainsToBlockCookiesFor>(connection, decoder, this, &NetworkProcess::updatePrevalentDomainsToBlockCookiesFor);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::IsGrandfathered::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::IsGrandfathered>(connection, decoder, this, &NetworkProcess::isGrandfathered);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::IsPrevalentResource::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::IsPrevalentResource>(connection, decoder, this, &NetworkProcess::isPrevalentResource);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::IsVeryPrevalentResource::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::IsVeryPrevalentResource>(connection, decoder, this, &NetworkProcess::isVeryPrevalentResource);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetAgeCapForClientSideCookies::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetAgeCapForClientSideCookies>(connection, decoder, this, &NetworkProcess::setAgeCapForClientSideCookies);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetLastSeen::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetLastSeen>(connection, decoder, this, &NetworkProcess::setLastSeen);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::MergeStatisticForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::MergeStatisticForTesting>(connection, decoder, this, &NetworkProcess::mergeStatisticForTesting);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::InsertExpiredStatisticForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::InsertExpiredStatisticForTesting>(connection, decoder, this, &NetworkProcess::insertExpiredStatisticForTesting);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetPrevalentResource::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetPrevalentResource>(connection, decoder, this, &NetworkProcess::setPrevalentResource);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetPrevalentResourceForDebugMode::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetPrevalentResourceForDebugMode>(connection, decoder, this, &NetworkProcess::setPrevalentResourceForDebugMode);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::IsResourceLoadStatisticsEphemeral::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::IsResourceLoadStatisticsEphemeral>(connection, decoder, this, &NetworkProcess::isResourceLoadStatisticsEphemeral);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::HadUserInteraction::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::HadUserInteraction>(connection, decoder, this, &NetworkProcess::hadUserInteraction);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::IsRelationshipOnlyInDatabaseOnce::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::IsRelationshipOnlyInDatabaseOnce>(connection, decoder, this, &NetworkProcess::isRelationshipOnlyInDatabaseOnce);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::HasLocalStorage::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::HasLocalStorage>(connection, decoder, this, &NetworkProcess::hasLocalStorage);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::GetAllStorageAccessEntries::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::GetAllStorageAccessEntries>(connection, decoder, this, &NetworkProcess::getAllStorageAccessEntries);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::IsRegisteredAsRedirectingTo::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::IsRegisteredAsRedirectingTo>(connection, decoder, this, &NetworkProcess::isRegisteredAsRedirectingTo);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::IsRegisteredAsSubFrameUnder::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::IsRegisteredAsSubFrameUnder>(connection, decoder, this, &NetworkProcess::isRegisteredAsSubFrameUnder);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::IsRegisteredAsSubresourceUnder::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::IsRegisteredAsSubresourceUnder>(connection, decoder, this, &NetworkProcess::isRegisteredAsSubresourceUnder);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::DomainIDExistsInDatabase::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::DomainIDExistsInDatabase>(connection, decoder, this, &NetworkProcess::domainIDExistsInDatabase);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::LogFrameNavigation::name()) {
        IPC::handleMessage<Messages::NetworkProcess::LogFrameNavigation>(decoder, this, &NetworkProcess::logFrameNavigation);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::LogUserInteraction::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::LogUserInteraction>(connection, decoder, this, &NetworkProcess::logUserInteraction);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::ResetParametersToDefaultValues::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ResetParametersToDefaultValues>(connection, decoder, this, &NetworkProcess::resetParametersToDefaultValues);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::ScheduleClearInMemoryAndPersistent::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ScheduleClearInMemoryAndPersistent>(connection, decoder, this, &NetworkProcess::scheduleClearInMemoryAndPersistent);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::ScheduleCookieBlockingUpdate::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ScheduleCookieBlockingUpdate>(connection, decoder, this, &NetworkProcess::scheduleCookieBlockingUpdate);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::ScheduleStatisticsAndDataRecordsProcessing::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ScheduleStatisticsAndDataRecordsProcessing>(connection, decoder, this, &NetworkProcess::scheduleStatisticsAndDataRecordsProcessing);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::StatisticsDatabaseHasAllTables::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::StatisticsDatabaseHasAllTables>(connection, decoder, this, &NetworkProcess::statisticsDatabaseHasAllTables);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetCacheMaxAgeCapForPrevalentResources::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetCacheMaxAgeCapForPrevalentResources>(connection, decoder, this, &NetworkProcess::setCacheMaxAgeCapForPrevalentResources);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetGrandfathered::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetGrandfathered>(connection, decoder, this, &NetworkProcess::setGrandfathered);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::GetResourceLoadStatisticsDataSummary::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::GetResourceLoadStatisticsDataSummary>(connection, decoder, this, &NetworkProcess::getResourceLoadStatisticsDataSummary);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetGrandfatheringTime::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetGrandfatheringTime>(connection, decoder, this, &NetworkProcess::setGrandfatheringTime);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetMaxStatisticsEntries::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetMaxStatisticsEntries>(connection, decoder, this, &NetworkProcess::setMaxStatisticsEntries);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetMinimumTimeBetweenDataRecordsRemoval::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetMinimumTimeBetweenDataRecordsRemoval>(connection, decoder, this, &NetworkProcess::setMinimumTimeBetweenDataRecordsRemoval);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetPruneEntriesDownTo::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetPruneEntriesDownTo>(connection, decoder, this, &NetworkProcess::setPruneEntriesDownTo);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetShouldClassifyResourcesBeforeDataRecordsRemoval::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetShouldClassifyResourcesBeforeDataRecordsRemoval>(connection, decoder, this, &NetworkProcess::setShouldClassifyResourcesBeforeDataRecordsRemoval);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetNotifyPagesWhenDataRecordsWereScanned::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetNotifyPagesWhenDataRecordsWereScanned>(connection, decoder, this, &NetworkProcess::setNotifyPagesWhenDataRecordsWereScanned);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetIsRunningResourceLoadStatisticsTest::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetIsRunningResourceLoadStatisticsTest>(connection, decoder, this, &NetworkProcess::setIsRunningResourceLoadStatisticsTest);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetResourceLoadStatisticsDebugMode::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetResourceLoadStatisticsDebugMode>(connection, decoder, this, &NetworkProcess::setResourceLoadStatisticsDebugMode);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetVeryPrevalentResource::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetVeryPrevalentResource>(connection, decoder, this, &NetworkProcess::setVeryPrevalentResource);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetSubframeUnderTopFrameDomain::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetSubframeUnderTopFrameDomain>(connection, decoder, this, &NetworkProcess::setSubframeUnderTopFrameDomain);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetSubresourceUnderTopFrameDomain::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetSubresourceUnderTopFrameDomain>(connection, decoder, this, &NetworkProcess::setSubresourceUnderTopFrameDomain);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetSubresourceUniqueRedirectTo::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetSubresourceUniqueRedirectTo>(connection, decoder, this, &NetworkProcess::setSubresourceUniqueRedirectTo);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetSubresourceUniqueRedirectFrom::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetSubresourceUniqueRedirectFrom>(connection, decoder, this, &NetworkProcess::setSubresourceUniqueRedirectFrom);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetTimeToLiveUserInteraction::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetTimeToLiveUserInteraction>(connection, decoder, this, &NetworkProcess::setTimeToLiveUserInteraction);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetTopFrameUniqueRedirectTo::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetTopFrameUniqueRedirectTo>(connection, decoder, this, &NetworkProcess::setTopFrameUniqueRedirectTo);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetTopFrameUniqueRedirectFrom::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetTopFrameUniqueRedirectFrom>(connection, decoder, this, &NetworkProcess::setTopFrameUniqueRedirectFrom);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::ResetCacheMaxAgeCapForPrevalentResources::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ResetCacheMaxAgeCapForPrevalentResources>(connection, decoder, this, &NetworkProcess::resetCacheMaxAgeCapForPrevalentResources);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::DidCommitCrossSiteLoadWithDataTransfer::name()) {
        IPC::handleMessage<Messages::NetworkProcess::DidCommitCrossSiteLoadWithDataTransfer>(decoder, this, &NetworkProcess::didCommitCrossSiteLoadWithDataTransfer);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetCrossSiteLoadWithLinkDecorationForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetCrossSiteLoadWithLinkDecorationForTesting>(connection, decoder, this, &NetworkProcess::setCrossSiteLoadWithLinkDecorationForTesting);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::ResetCrossSiteLoadsWithLinkDecorationForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ResetCrossSiteLoadsWithLinkDecorationForTesting>(connection, decoder, this, &NetworkProcess::resetCrossSiteLoadsWithLinkDecorationForTesting);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::DeleteCookiesForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::DeleteCookiesForTesting>(connection, decoder, this, &NetworkProcess::deleteCookiesForTesting);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::HasIsolatedSession::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::HasIsolatedSession>(connection, decoder, this, &NetworkProcess::hasIsolatedSession);
        return;
    }
#endif
#if (ENABLE(RESOURCE_LOAD_STATISTICS) && ENABLE(APP_BOUND_DOMAINS))
    if (decoder.messageName() == Messages::NetworkProcess::SetAppBoundDomainsForResourceLoadStatistics::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetAppBoundDomainsForResourceLoadStatistics>(connection, decoder, this, &NetworkProcess::setAppBoundDomainsForResourceLoadStatistics);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetShouldDowngradeReferrerForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetShouldDowngradeReferrerForTesting>(connection, decoder, this, &NetworkProcess::setShouldDowngradeReferrerForTesting);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetThirdPartyCookieBlockingMode::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetThirdPartyCookieBlockingMode>(connection, decoder, this, &NetworkProcess::setThirdPartyCookieBlockingMode);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetShouldEnbleSameSiteStrictEnforcementForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetShouldEnbleSameSiteStrictEnforcementForTesting>(connection, decoder, this, &NetworkProcess::setShouldEnbleSameSiteStrictEnforcementForTesting);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetFirstPartyWebsiteDataRemovalModeForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetFirstPartyWebsiteDataRemovalModeForTesting>(connection, decoder, this, &NetworkProcess::setFirstPartyWebsiteDataRemovalModeForTesting);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetToSameSiteStrictCookiesForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetToSameSiteStrictCookiesForTesting>(connection, decoder, this, &NetworkProcess::setToSameSiteStrictCookiesForTesting);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetFirstPartyHostCNAMEDomainForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetFirstPartyHostCNAMEDomainForTesting>(connection, decoder, this, &NetworkProcess::setFirstPartyHostCNAMEDomainForTesting);
        return;
    }
#endif
#if ENABLE(RESOURCE_LOAD_STATISTICS)
    if (decoder.messageName() == Messages::NetworkProcess::SetThirdPartyCNAMEDomainForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetThirdPartyCNAMEDomainForTesting>(connection, decoder, this, &NetworkProcess::setThirdPartyCNAMEDomainForTesting);
        return;
    }
#endif
    if (decoder.messageName() == Messages::NetworkProcess::SetPrivateClickMeasurementDebugMode::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetPrivateClickMeasurementDebugMode>(decoder, this, &NetworkProcess::setPrivateClickMeasurementDebugMode);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SetSessionIsControlledByAutomation::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetSessionIsControlledByAutomation>(decoder, this, &NetworkProcess::setSessionIsControlledByAutomation);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::RegisterURLSchemeAsSecure::name()) {
        IPC::handleMessage<Messages::NetworkProcess::RegisterURLSchemeAsSecure>(decoder, this, &NetworkProcess::registerURLSchemeAsSecure);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::RegisterURLSchemeAsBypassingContentSecurityPolicy::name()) {
        IPC::handleMessage<Messages::NetworkProcess::RegisterURLSchemeAsBypassingContentSecurityPolicy>(decoder, this, &NetworkProcess::registerURLSchemeAsBypassingContentSecurityPolicy);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::RegisterURLSchemeAsLocal::name()) {
        IPC::handleMessage<Messages::NetworkProcess::RegisterURLSchemeAsLocal>(decoder, this, &NetworkProcess::registerURLSchemeAsLocal);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::RegisterURLSchemeAsNoAccess::name()) {
        IPC::handleMessage<Messages::NetworkProcess::RegisterURLSchemeAsNoAccess>(decoder, this, &NetworkProcess::registerURLSchemeAsNoAccess);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SetCacheStorageParameters::name()) {
        IPC::handleMessage<Messages::NetworkProcess::SetCacheStorageParameters>(decoder, this, &NetworkProcess::setCacheStorageParameters);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SyncLocalStorage::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SyncLocalStorage>(connection, decoder, this, &NetworkProcess::syncLocalStorage);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::StorePrivateClickMeasurement::name()) {
        IPC::handleMessage<Messages::NetworkProcess::StorePrivateClickMeasurement>(decoder, this, &NetworkProcess::storePrivateClickMeasurement);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::DumpPrivateClickMeasurement::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::DumpPrivateClickMeasurement>(connection, decoder, this, &NetworkProcess::dumpPrivateClickMeasurement);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ClearPrivateClickMeasurement::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ClearPrivateClickMeasurement>(connection, decoder, this, &NetworkProcess::clearPrivateClickMeasurement);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SetPrivateClickMeasurementOverrideTimerForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetPrivateClickMeasurementOverrideTimerForTesting>(connection, decoder, this, &NetworkProcess::setPrivateClickMeasurementOverrideTimerForTesting);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::MarkAttributedPrivateClickMeasurementsAsExpiredForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::MarkAttributedPrivateClickMeasurementsAsExpiredForTesting>(connection, decoder, this, &NetworkProcess::markAttributedPrivateClickMeasurementsAsExpiredForTesting);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SimulateResourceLoadStatisticsSessionRestart::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SimulateResourceLoadStatisticsSessionRestart>(connection, decoder, this, &NetworkProcess::simulateResourceLoadStatisticsSessionRestart);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SetPrivateClickMeasurementTokenPublicKeyURLForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetPrivateClickMeasurementTokenPublicKeyURLForTesting>(connection, decoder, this, &NetworkProcess::setPrivateClickMeasurementTokenPublicKeyURLForTesting);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SetPrivateClickMeasurementTokenSignatureURLForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetPrivateClickMeasurementTokenSignatureURLForTesting>(connection, decoder, this, &NetworkProcess::setPrivateClickMeasurementTokenSignatureURLForTesting);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SetPrivateClickMeasurementAttributionReportURLForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetPrivateClickMeasurementAttributionReportURLForTesting>(connection, decoder, this, &NetworkProcess::setPrivateClickMeasurementAttributionReportURLForTesting);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::MarkPrivateClickMeasurementsAsExpiredForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::MarkPrivateClickMeasurementsAsExpiredForTesting>(connection, decoder, this, &NetworkProcess::markPrivateClickMeasurementsAsExpiredForTesting);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SetFraudPreventionValuesForTesting::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::SetFraudPreventionValuesForTesting>(connection, decoder, this, &NetworkProcess::setFraudPreventionValuesForTesting);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::GetLocalStorageOriginDetails::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::GetLocalStorageOriginDetails>(connection, decoder, this, &NetworkProcess::getLocalStorageOriginDetails);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ResetQuota::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ResetQuota>(connection, decoder, this, &NetworkProcess::resetQuota);
        return;
    }
#if ENABLE(APP_BOUND_DOMAINS)
    if (decoder.messageName() == Messages::NetworkProcess::HasAppBoundSession::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::HasAppBoundSession>(connection, decoder, this, &NetworkProcess::hasAppBoundSession);
        return;
    }
#endif
#if ENABLE(APP_BOUND_DOMAINS)
    if (decoder.messageName() == Messages::NetworkProcess::ClearAppBoundSession::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ClearAppBoundSession>(connection, decoder, this, &NetworkProcess::clearAppBoundSession);
        return;
    }
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    if (decoder.messageName() == Messages::NetworkProcess::DisableServiceWorkerEntitlement::name()) {
        IPC::handleMessage<Messages::NetworkProcess::DisableServiceWorkerEntitlement>(decoder, this, &NetworkProcess::disableServiceWorkerEntitlement);
        return;
    }
#endif
#if PLATFORM(IOS_FAMILY) && !PLATFORM(MACCATALYST)
    if (decoder.messageName() == Messages::NetworkProcess::ClearServiceWorkerEntitlementOverride::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ClearServiceWorkerEntitlementOverride>(connection, decoder, this, &NetworkProcess::clearServiceWorkerEntitlementOverride);
        return;
    }
#endif
    if (decoder.messageName() == Messages::NetworkProcess::UpdateBundleIdentifier::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::UpdateBundleIdentifier>(connection, decoder, this, &NetworkProcess::updateBundleIdentifier);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ClearBundleIdentifier::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ClearBundleIdentifier>(connection, decoder, this, &NetworkProcess::clearBundleIdentifier);
        return;
    }
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::NetworkProcess::AppBoundNavigationData::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::AppBoundNavigationData>(connection, decoder, this, &NetworkProcess::appBoundNavigationData);
        return;
    }
#endif
#if PLATFORM(COCOA)
    if (decoder.messageName() == Messages::NetworkProcess::ClearAppBoundNavigationData::name()) {
        IPC::handleMessageAsync<Messages::NetworkProcess::ClearAppBoundNavigationData>(connection, decoder, this, &NetworkProcess::clearAppBoundNavigationData);
        return;
    }
#endif
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    ASSERT_NOT_REACHED();
}

void NetworkProcess::didReceiveSyncNetworkProcessMessage(IPC::Connection& connection, IPC::Decoder& decoder, std::unique_ptr<IPC::Encoder>& replyEncoder)
{
    auto protectedThis = makeRef(*this);
    if (decoder.messageName() == Messages::NetworkProcess::SetAllowsAnySSLCertificateForWebSocket::name()) {
        IPC::handleMessageSynchronous<Messages::NetworkProcess::SetAllowsAnySSLCertificateForWebSocket>(connection, decoder, replyEncoder, this, &NetworkProcess::setAllowsAnySSLCertificateForWebSocket);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SetCacheModelSynchronouslyForTesting::name()) {
        IPC::handleMessageSynchronous<Messages::NetworkProcess::SetCacheModelSynchronouslyForTesting>(connection, decoder, replyEncoder, this, &NetworkProcess::setCacheModelSynchronouslyForTesting);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ProcessWillSuspendImminentlyForTestingSync::name()) {
        IPC::handleMessageSynchronous<Messages::NetworkProcess::ProcessWillSuspendImminentlyForTestingSync>(connection, decoder, replyEncoder, this, &NetworkProcess::processWillSuspendImminentlyForTestingSync);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::SetServiceWorkerFetchTimeoutForTesting::name()) {
        IPC::handleMessageSynchronous<Messages::NetworkProcess::SetServiceWorkerFetchTimeoutForTesting>(connection, decoder, replyEncoder, this, &NetworkProcess::setServiceWorkerFetchTimeoutForTesting);
        return;
    }
    if (decoder.messageName() == Messages::NetworkProcess::ResetServiceWorkerFetchTimeoutForTesting::name()) {
        IPC::handleMessageSynchronous<Messages::NetworkProcess::ResetServiceWorkerFetchTimeoutForTesting>(connection, decoder, replyEncoder, this, &NetworkProcess::resetServiceWorkerFetchTimeoutForTesting);
        return;
    }
    UNUSED_PARAM(connection);
    UNUSED_PARAM(decoder);
    UNUSED_PARAM(replyEncoder);
    ASSERT_NOT_REACHED();
}

} // namespace WebKit
